UP and DOWN for the NRI calculationInternaly used function to detemine subjects who belong to UP
and DOWN.
get.uppdwn(time, event, objs, flag.mdl, flag.prd, flag.rsk, t0, updown,
cut, get.risk, msg = FALSE)Vector of follow up times.
Vector of event indicators, 1 for event of interest, 0 for censoring.
List of data.
Logical values to determine the type of calculation based on the input data.
Scalar value indicating a time to determine evnet/non-event.
Character to specify the method to determine UP and
DOWN.
Scalar or vector to specify the cutoff value(s) of predicted risks
for determining UP and DOWN.
See also cut in nricens or nribin.
R function to calculate individual risks.
Logical value to display computation process.
Setting FALSE leads silent execution.