Internaly used function by nribin.
In the comparison for binary models, it is possible to use directly
when UP and DOWN subjects are known.
nribin.count.main(event, upp, dwn)Vector of event indicators, 1 for event of interest, 0 for non-event.
Vector of logical values to determine subjects who belong to
UP and DOWN, respectively.